==> atlassian_connect_host-0.3.4%2B1.tar.gz: lib/host_model.dart <==
library ac_dart.host_model;

import 'package:path/path.dart' as path;
import 'package:option/option.dart';
import 'package:constrain/constrain.dart';

class AddonHost {
  @NotNull()
  final String key;

  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final Option<String> addonSecret;

  AddonHost(this.key, this.baseUrl, [String addonSecret])
      : this.addonSecret = new Option(addonSecret);
}



class ProductType {
  final int ordinal;
  final String literal;

  const ProductType(this.ordinal, this.literal);

  static const ProductType jira = const ProductType(1, "jira");
  static const ProductType confluence = const ProductType(2, "confluence");

  static ProductType fromLiteral(String literal) {
    // TODO: ugly impl
    switch (literal) {
      case "jira":
        return jira;
      case "confluence":
        return confluence;
      default:
        return null;
    }
  }

  String toString() => literal;
}

class AcHostDetails extends Object with _AcHostDetailsMixin {
  @NotNull()
  final String key;

  @NotNull()
  final ProductType productType;

  final String publicKey;

  @NotNull()
  final Uri baseUrl;

  AcHostDetails(this.key, this.productType, this.publicKey, this.baseUrl);

  String toString() => 'AcHostDetails[$key, $productType, $baseUrl]';

  AcHostDetails.fromJson(Map<String, Object> jsonMap): this(jsonMap['key'],
      ProductType.fromLiteral(jsonMap['productType']), jsonMap['publicKey'],
      Uri.parse(jsonMap['baseUrl']));

}

class AcHostRegistration extends Object with _AcHostRegistrationMixin {
  @NotNull()
  final int id;

  @NotNull()
  final AcHostDetails hostDetails;

  @NotNull()
  final String sharedSecret;

  AcHostRegistration(this.id, this.hostDetails, this.sharedSecret);

  AcHostRegistration.fromJson(Map<String, Object> jsonMap)
      : this(0, new AcHostDetails.fromJson(jsonMap['hostDetails']),
          jsonMap['sharedSecret']);

}

class MutableAcHostDetails extends Object with _AcHostDetailsMixin implements
    AcHostDetails {
  String key;
  ProductType productType;
  String publicKey;
  Uri baseUrl;

  AcHostDetails toImmutable() => new AcHostDetails(key, productType, publicKey,
      baseUrl);
}

class MutableAcHostRegistration extends Object with _AcHostRegistrationMixin
    implements AcHostRegistration {
  int id;
  MutableAcHostDetails hostDetails;
  String sharedSecret;

  AcHostRegistration toImmutable() => new AcHostRegistration(id,
      hostDetails.toImmutable(), sharedSecret);
}

abstract class _AcHostDetailsMixin {
  // TODO: remove from here
  static const String _consumerInfoPath =
      "/plugins/servlet/oauth/consumer-info";
  String get key;
  ProductType get productType;
  String get publicKey;
  Uri get baseUrl;

  Uri get consumerInfoUrl => Uri.parse(path.join(baseUrl.origin,
      _consumerInfoPath));

  Map<String, Object> toJson() => {
    'key': key,
    'productType': productType.literal,
    'publicKey': publicKey,
    'baseUrl': baseUrl.toString()
  };

}

abstract class _AcHostRegistrationMixin {
  int get id;
  MutableAcHostDetails get hostDetails;
  String get sharedSecret;

  Map<String, Object> toJson() => {
    'sharedSecret': sharedSecret, // TODO: encrypt??
    'hostDetails': hostDetails.toJson()
  };

  String toString() => 'AcHostRegistration[$id, $hostDetails]';

}

==> atlassian_connect_host-0.3.5%2B1.tar.gz: lib/host_model.dart <==
library ac_dart.host_model;

import 'package:path/path.dart' as path;
import 'package:option/option.dart';
import 'package:constrain/constrain.dart';

class AddonHost {
  @NotNull()
  final String key;

  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final Option<String> addonSecret;

  AddonHost(this.key, this.baseUrl, [String addonSecret])
      : this.addonSecret = new Option(addonSecret);
}



class ProductType {
  final int ordinal;
  final String literal;

  const ProductType(this.ordinal, this.literal);

  static const ProductType jira = const ProductType(1, "jira");
  static const ProductType confluence = const ProductType(2, "confluence");
  static const ProductType bitbucket = const ProductType(3, "bitbucket");

  static final Map<String, ProductType> _values = {
      jira.literal : jira,
      confluence.literal: confluence,
      bitbucket.literal: bitbucket
  };
  
  static ProductType fromLiteral(String literal) => _values[literal];

  String toString() => literal;
}

class AcHostDetails extends Object with _AcHostDetailsMixin {
  @NotNull()
  final String key;

  @NotNull()
  final ProductType productType;

  final String publicKey;

  @NotNull()
  final Uri baseUrl;

  AcHostDetails(this.key, this.productType, this.publicKey, this.baseUrl);

  String toString() => 'AcHostDetails[$key, $productType, $baseUrl]';

  AcHostDetails.fromJson(Map<String, Object> jsonMap): this(jsonMap['key'],
      ProductType.fromLiteral(jsonMap['productType']), jsonMap['publicKey'],
      Uri.parse(jsonMap['baseUrl']));
  
  Map toJson() => {
    'key': key,
    'productType': productType.toString(),
    'baseUrl': baseUrl.toString(),
    'publicKey': publicKey
  };

}

class AcHostRegistration extends Object with _AcHostRegistrationMixin {
  @NotNull()
  final int id;

  @NotNull()
  final AcHostDetails hostDetails;

  @NotNull()
  final String sharedSecret;

  AcHostRegistration(this.id, this.hostDetails, this.sharedSecret);

  AcHostRegistration.fromJson(Map<String, Object> jsonMap)
      : this(0, new AcHostDetails.fromJson(jsonMap['hostDetails']),
          jsonMap['sharedSecret']);

  Map toJson() => {
    'id': id,
    'hostDetails': hostDetails.toJson(),
    'sharedSecret': sharedSecret,
  };
}

class MutableAcHostDetails extends Object with _AcHostDetailsMixin implements
    AcHostDetails {
  String key;
  ProductType productType;
  String publicKey;
  Uri baseUrl;

  AcHostDetails toImmutable() => new AcHostDetails(key, productType, publicKey,
      baseUrl);
}

class MutableAcHostRegistration extends Object with _AcHostRegistrationMixin
    implements AcHostRegistration {
  int id;
  MutableAcHostDetails hostDetails;
  String sharedSecret;

  AcHostRegistration toImmutable() => new AcHostRegistration(id,
      hostDetails.toImmutable(), sharedSecret);
}

abstract class _AcHostDetailsMixin {
  // TODO: remove from here
  static const String _consumerInfoPath =
      "/plugins/servlet/oauth/consumer-info";
  String get key;
  ProductType get productType;
  String get publicKey;
  Uri get baseUrl;

  Uri get consumerInfoUrl => Uri.parse(path.join(baseUrl.origin,
      _consumerInfoPath));

  Map<String, Object> toJson() => {
    'key': key,
    'productType': productType.literal,
    'publicKey': publicKey,
    'baseUrl': baseUrl.toString()
  };

}

abstract class _AcHostRegistrationMixin {
  int get id;
  MutableAcHostDetails get hostDetails;
  String get sharedSecret;

  Map<String, Object> toJson() => {
    'sharedSecret': sharedSecret, // TODO: encrypt??
    'hostDetails': hostDetails.toJson()
  };

  String toString() => 'AcHostRegistration[$id, $hostDetails]';

}
